diff --git a/etc/fslconf/createFSLWrapper.sh b/etc/fslconf/createFSLWrapper.sh
index 101e50506f366fb8f3254173665f86208a8c362b..c80f753b02fbe757337b3dd84371145336487f19 100755
--- a/etc/fslconf/createFSLWrapper.sh
+++ b/etc/fslconf/createFSLWrapper.sh
@@ -1,6 +1,6 @@
 #!/bin/sh
 #
 # Create wrapper scripts in $FSLDIR/share/bin/ which invoke commands that
 # are installed in $FSLDIR/bin/.
 #
 # This script is used to create isolated versions of all executables
@@ -14,8 +14,8 @@
 #
 # Early versions of this script would create symlinks from $FSLDIR/bin/ into
 # $FSLDIR/fslpython/envs/fslpython/bin/ (and, later, into
 # $FSLDIR/share/bin/). However, wrapper scripts are now used instead to work
 # around a couple of problems:
 #
 #  - We need python executables to exclusively use the libraries installed in
 #    the FSL conda environment. Users may have other Python environments
@@ -45,12 +45,18 @@ case "$PREFIX" in "$FSLDIR"*)
 
   for script in $targets; do
     sourceScript="${PREFIX}/bin/$script"
-    targetScript="${FSLDIR}/share/bin/$script"
+    targetScript="${FSLDIR}/share/fsl/bin/$script"
 
     if [ ! -f "$sourceScript" ]; then
       continue
     fi
 
+    # create share/fsl/bin/ if it doesn't
+    # already exist
+    if [ ! -e "$FSLDIR/share/fsl/bin" ]; then
+      mkdir -p "$FSLDIR/share/fsl/bin"
+    fi
+
     # remove target script if it already exists
     if [ -e "$targetScript" ]; then
       rm "$targetScript"
@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Create wrapper scripts in $FSLDIR/share/bin/ which invoke commands that
+# Create wrapper scripts in $FSLDIR/share/fsl/bin/ which invoke commands that
 # are installed in $FSLDIR/bin/.
 #
@@ -14,8 +14,8 @@
 # Early versions of this script would create symlinks from $FSLDIR/bin/ into
 # $FSLDIR/fslpython/envs/fslpython/bin/ (and, later, into
-# $FSLDIR/share/bin/). However, wrapper scripts are now used instead to work
-# around a couple of problems:
+# $FSLDIR/share/fsl/bin/). However, wrapper scripts are now used instead to
+# work around a couple of problems:
 #
 #  - We need python executables to exclusively use the libraries installed in
diff --git a/etc/fslconf/removeFSLWrapper.sh b/etc/fslconf/removeFSLWrapper.sh
index 625409beeade83aa6b9959921550bcb605139f7b..675e5986aaebd005f29d1f94d62a56864e5f877e 100755
--- a/etc/fslconf/removeFSLWrapper.sh
+++ b/etc/fslconf/removeFSLWrapper.sh
@@ -1,6 +1,6 @@
 #!/bin/sh
 #
 # Remove wrapper script/links in $FSLDIR/share/bin/ which invoke commands
 # that are installed in $FSLDIR/bin/.  See createFSLWrapper.sh for more
 # information.
 
@@ -14,7 +14,7 @@ fi
 case "$PREFIX" in "$FSLDIR"*)
 
  for script in $targets; do
-    targetScript="${FSLDIR}/share/bin/$script"
+    targetScript="${FSLDIR}/share/fsl/bin/$script"
 
     if [ -f "$targetScript" ]; then
       rm "$targetScript"
@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Remove wrapper script/links in $FSLDIR/share/bin/ which invoke commands
+# Remove wrapper script/links in $FSLDIR/share/fsl/bin/ which invoke commands
 # that are installed in $FSLDIR/bin/.  See createFSLWrapper.sh for more
 # information.